==> james-project-3.4.0-source-release.zip: james-project-3.4.0/protocols/smtp/src/main/java/org/apache/james/protocols/smtp/hook/SimpleHook.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.protocols.smtp.hook;

import org.apache.commons.configuration2.Configuration;
import org.apache.commons.configuration2.ex.ConfigurationException;
import org.apache.james.core.MailAddress;
import org.apache.james.core.MaybeSender;
import org.apache.james.protocols.smtp.MailEnvelope;
import org.apache.james.protocols.smtp.SMTPSession;


/**
 * Simple {@link Hook} implementation which can be used as base class when writing simple {@link Hook}'s
 * 
 * The SMTP-Server will just accept email with this {@link Hook} in place and discard it
 *
 */
public class SimpleHook implements HeloHook, MailHook, RcptHook, MessageHook {

    @Override
    public void init(Configuration config) throws ConfigurationException {

    }

    @Override
    public void destroy() {

    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode#OK}
     */
    @Override
    public HookResult onMessage(SMTPSession session, MailEnvelope mail) {
        return HookResult.OK;
    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode#DECLINED}
     */
    @Override
    public HookResult doRcpt(SMTPSession session, MaybeSender sender, MailAddress rcpt) {
        return HookResult.DECLINED;

    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode#DECLINED}
     */
    @Override
    public HookResult doMail(SMTPSession session, MaybeSender sender) {
        return HookResult.DECLINED;

    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode#DECLINED}
     */
    @Override
    public HookResult doHelo(SMTPSession session, String helo) {
        return HookResult.DECLINED;
    }

}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/protocols/smtp/src/main/java/org/apache/james/protocols/smtp/hook/SimpleHook.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.protocols.smtp.hook;

import org.apache.james.core.MailAddress;
import org.apache.james.core.MaybeSender;
import org.apache.james.protocols.smtp.MailEnvelope;
import org.apache.james.protocols.smtp.SMTPSession;

/**
 * Simple {@link Hook} implementation which can be used as base class when writing simple {@link Hook}'s
 * 
 * The SMTP-Server will just accept email with this {@link Hook} in place and discard it
 */
public class SimpleHook implements HeloHook, MailHook, RcptHook, MessageHook {

    /**
     * Return {@link HookResult} with {@link HookReturnCode.Action#OK}
     */
    @Override
    public HookResult onMessage(SMTPSession session, MailEnvelope mail) {
        return HookResult.OK;
    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode.Action#DECLINED}
     */
    @Override
    public HookResult doRcpt(SMTPSession session, MaybeSender sender, MailAddress rcpt) {
        return HookResult.DECLINED;

    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode.Action#DECLINED}
     */
    @Override
    public HookResult doMail(SMTPSession session, MaybeSender sender) {
        return HookResult.DECLINED;

    }

    /**
     * Return {@link HookResult} with {@link HookReturnCode.Action#DECLINED}
     */
    @Override
    public HookResult doHelo(SMTPSession session, String helo) {
        return HookResult.DECLINED;
    }

}
